@@ -1375,13 +1375,14 @@ clearlooks_draw_menuitem (cairo_t *cr,
 {
 	CairoColor *fill = (CairoColor*)&colors->spot[1];
 	CairoColor fill_shade;
-	CairoColor *border = (CairoColor*)&colors->spot[2];
+	CairoColor border = colors->spot[2];
 	cairo_pattern_t *pattern;
 
+	ge_shade_color (&border, 1.05, &border);
 	ge_shade_color (fill, 0.85, &fill_shade);
 	cairo_set_line_width (cr, 1.0);
 
-	cairo_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1);
+	ge_cairo_rounded_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1, widget->radius, widget->corners);
 
 	pattern = cairo_pattern_create_linear (x, y, x, y + height);
 	cairo_pattern_add_color_stop_rgb (pattern, 0,   fill->r, fill->g, fill->b);
@@ -1391,7 +1392,7 @@ clearlooks_draw_menuitem (cairo_t *cr,
 	cairo_fill_preserve  (cr);
 	cairo_pattern_destroy (pattern);
 
-	ge_cairo_set_color (cr, border);
+	ge_cairo_set_color (cr, &border);
 	cairo_stroke (cr);
 
 }
@@ -1404,9 +1405,10 @@ clearlooks_draw_menubaritem (cairo_t *cr,
 {
 	CairoColor *fill = (CairoColor*)&colors->spot[1];
 	CairoColor fill_shade;
-	CairoColor *border = (CairoColor*)&colors->spot[2];
+	CairoColor border = colors->spot[2];
 	cairo_pattern_t *pattern;
 	
+	ge_shade_color (&border, 1.05, &border);
 	ge_shade_color (fill, 0.85, &fill_shade);
 	
 	cairo_set_line_width (cr, 1.0);
@@ -1421,7 +1423,7 @@ clearlooks_draw_menubaritem (cairo_t *cr,
 	cairo_fill_preserve  (cr);
 	cairo_pattern_destroy (pattern);
 
-	ge_cairo_set_color (cr, border);
+	ge_cairo_set_color (cr, &border);
 	cairo_stroke_preserve (cr);
 }
 
@@ -1558,22 +1560,24 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 		pattern = cairo_pattern_create_linear (0, 0, width, 0);
 				
 	s2 = colors->bg[widget->state_type];
-	ge_shade_color(&s2, 1.1, &s1);
+	ge_shade_color(&s2, 1.06, &s1);
 	ge_shade_color(&s2, 0.98, &s3); 
-	ge_shade_color(&s2, 0.93, &s4); 
+	ge_shade_color(&s2, 0.94, &s4); 
 	
 	cairo_pattern_add_color_stop_rgb(pattern, 0,    s1.r, s1.g, s1.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 0.3, 	s2.r, s2.g, s2.b);
-	cairo_pattern_add_color_stop_rgb(pattern, 0.7, 	s3.r, s3.g, s3.b);
+	cairo_pattern_add_color_stop_rgb(pattern, 0.5,	s2.r, s2.g, s2.b);
+	cairo_pattern_add_color_stop_rgb(pattern, 0.7,	s3.r, s3.g, s3.b);
 	cairo_pattern_add_color_stop_rgb(pattern, 1.0,  s4.r, s4.g, s4.b);
 	cairo_set_source (cr, pattern);
 	cairo_fill (cr);
 	cairo_pattern_destroy (pattern);
-
-	ge_cairo_rounded_rectangle (cr, 0.5, 0.5, width-1, height-1, radius, corners);
 	
+	cairo_translate (cr, 0.5, 0.5);
+	clearlooks_draw_top_left_highlight (cr, &s2, widget, width, height, (stepper->stepper == CL_STEPPER_A) ? radius : 0);
+	cairo_translate (cr, -0.5, -0.5);
+	
+	ge_cairo_rounded_rectangle (cr, 0.5, 0.5, width-1, height-1, radius, corners);
 	clearlooks_set_border_gradient (cr, &border, 1.2, (scrollbar->horizontal ? 0 : width), (scrollbar->horizontal ? height: 0)); 
-
 	cairo_stroke (cr);
 	
 	cairo_translate (cr, 0.5, 0.5);
@@ -1638,8 +1642,8 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 		
 		pattern = cairo_pattern_create_linear (1, 1, 1, height-2);
 		cairo_pattern_add_color_stop_rgb (pattern, 0,   shade1.r, shade1.g, shade1.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 0.5, shade2.r, shade2.g, shade2.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 0.5, shade3.r, shade3.g, shade3.b);	
+		cairo_pattern_add_color_stop_rgb (pattern, 0.5,	shade2.r, shade2.g, shade2.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 0.5,	shade3.r, shade3.g, shade3.b);	
 		cairo_pattern_add_color_stop_rgb (pattern, 1, 	fill.r,  fill.g,  fill.b);
 		cairo_rectangle (cr, 1, 1, width-2, height-2);
 		cairo_set_source (cr, pattern);
@@ -1655,7 +1659,7 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 	else
 	{
 		CairoColor border;
-		CairoColor s1, s2, s3, s4;
+		CairoColor s1, s2, s3, s4, s5;
 		cairo_pattern_t *pattern;
 		int bar_x, i;
 		CairoColor *dark  = (CairoColor*)&colors->shade[4];
@@ -1664,14 +1668,14 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 		ge_shade_color(&colors->shade[6], 1.05, &border);
 		
 		s2 = colors->bg[widget->state_type];
-		ge_shade_color(&s2, 1.1, &s1);
+		ge_shade_color(&s2, 1.06, &s1);
 		ge_shade_color(&s2, 0.98, &s3); 
-		ge_shade_color(&s2, 0.93, &s4); 
+		ge_shade_color(&s2, 0.94, &s4); 
 	
 		pattern = cairo_pattern_create_linear(1, 1, 1, height-1);
 		cairo_pattern_add_color_stop_rgb(pattern, 0,    s1.r, s1.g, s1.b);
-		cairo_pattern_add_color_stop_rgb(pattern, 0.3, 	s2.r, s2.g, s2.b);
-		cairo_pattern_add_color_stop_rgb(pattern, 0.7, 	s3.r, s3.g, s3.b);
+		cairo_pattern_add_color_stop_rgb(pattern, 0.5,	s2.r, s2.g, s2.b);
+		cairo_pattern_add_color_stop_rgb(pattern, 0.7,	s3.r, s3.g, s3.b);
 		cairo_pattern_add_color_stop_rgb(pattern, 1.0,  s4.r, s4.g, s4.b);
 
 		cairo_rectangle (cr, 1, 1, width-2, height-2);
@@ -1682,6 +1686,13 @@ clearlooks_draw_scrollbar_slider (cairo_t *cr,
 		clearlooks_set_border_gradient (cr, &border, 1.2, 0, height); 
 		ge_cairo_stroke_rectangle (cr, 0.5, 0.5, width-1, height-1);
 		
+		cairo_move_to (cr, 1.5, height-1.5);
+		cairo_line_to (cr, 1.5, 1.5);
+		cairo_line_to (cr, width-1.5, 1.5);
+		ge_shade_color (&s2, 1.3, &s5);
+		cairo_set_source_rgba(cr, s5.r, s5.g, s5.b, 0.5);
+		cairo_stroke(cr);
+		
 		/* draw handles */
 		cairo_set_line_width (cr, 1);
 		
@@ -1799,30 +1810,67 @@ clearlooks_draw_resize_grip (cairo_t *cr,
                              const ResizeGripParameters      *grip,
                              int x, int y, int width, int height)
 {
-	CairoColor *dark   = (CairoColor*)&colors->shade[4];
+	const CairoColor *dark   = &colors->shade[4];
 	CairoColor hilight;
 	int lx, ly;
-
+	int x_down;
+	int y_down;
+	int dots;
+	
 	ge_shade_color (dark, 1.5, &hilight);
 
-	cairo_set_line_width (cr, 1);
-	
-	for (ly=0; ly<4; ly++) /* vertically, four rows of dots */
+	/* The number of dots fitting into the area. Just hardcoded to 4 right now. */
+	/* dots = MIN (width - 2, height - 2) / 3; */
+	dots = 4;
+
+	cairo_save (cr);
+
+	switch (grip->edge)
 	{
-		for (lx=0; lx<=ly; lx++) /* horizontally */
+		case CL_WINDOW_EDGE_NORTH_EAST:
+			x_down = 0;
+			y_down = 0;
+			cairo_translate (cr, x + width - 3*dots + 2, y + 1);
+		break;
+		case CL_WINDOW_EDGE_SOUTH_EAST:
+			x_down = 0;
+			y_down = 1;
+			cairo_translate (cr, x + width - 3*dots + 2, y + height - 3*dots + 2);
+		break;
+		case CL_WINDOW_EDGE_SOUTH_WEST:
+			x_down = 1;
+			y_down = 1;
+			cairo_translate (cr, x + 1, y + height - 3*dots + 2);
+		break;
+		case CL_WINDOW_EDGE_NORTH_WEST:
+			x_down = 1;
+			y_down = 0;
+			cairo_translate (cr, x + 1, y + 1);
+		break;
+		default:
+			/* Not implemented. */
+			return;
+	}
+
+	for (lx = 0; lx < dots; lx++) /* horizontally */
+	{
+		for (ly = 0; ly <= lx; ly++) /* vertically */
 		{
-			int ny = (3.5-ly) * 3;
-			int nx = lx * 3;
+			int mx, my;
+			mx = x_down * dots + (1 - x_down * 2) * lx - x_down;
+			my = y_down * dots + (1 - y_down * 2) * ly - y_down;
 
 			cairo_set_source_rgb (cr, hilight.r, hilight.g, hilight.b);
-			cairo_rectangle (cr, x+width-nx-1, y+height-ny-1, 2, 2);
+			cairo_rectangle (cr, mx*3-1, my*3-1, 2, 2);
 			cairo_fill (cr);
 
 			cairo_set_source_rgb (cr, dark->r, dark->g, dark->b);
-			cairo_rectangle (cr, x+width-nx-1, y+height-ny-1, 1, 1);
+			cairo_rectangle (cr, mx*3-1, my*3-1, 1, 1);
 			cairo_fill (cr);
 		}
 	}
+
+	cairo_restore (cr);
 }
 
 static void
@@ -1999,44 +2047,48 @@ static void
 clearlooks_draw_normal_arrow (cairo_t *cr, CairoColor *color,
                               double x, double y, double width, double height)
 {
-	const int ARROW_WIDTH  = 7.0;
-	const float ARROW_HEIGHT = 3.0;
+	double arrow_width;
+	double arrow_height;
+	double line_width_2;
 
-	cairo_set_line_width (cr, 1.5);
+	cairo_save (cr);
+
+	arrow_width = MIN (height * 2.0 + MAX (1.0, ceil (height * 2.0 / 6.0 * 2.0) / 2.0) / 2.0, width);
+	line_width_2 = MAX (1.0, ceil (arrow_width / 6.0 * 2.0) / 2.0) / 2.0;
+	arrow_height = arrow_width / 2.0 + line_width_2;
 	
-	cairo_move_to   (cr, -ARROW_WIDTH/2, -ARROW_HEIGHT/2);
-	cairo_line_to   (cr, 0, ARROW_HEIGHT/2);
-	cairo_line_to   (cr, ARROW_WIDTH/2, -ARROW_HEIGHT/2);
+	cairo_translate (cr, x, y - arrow_height / 2.0);
+
+	cairo_move_to (cr, -arrow_width / 2.0, line_width_2);
+	cairo_line_to (cr, -arrow_width / 2.0 + line_width_2, 0);
+	/* cairo_line_to (cr, 0, arrow_height - line_width_2); */
+	cairo_arc_negative (cr, 0, arrow_height - 2*line_width_2 - 2*line_width_2 * sqrt(2), 2*line_width_2, G_PI_2 + G_PI_4, G_PI_4);
+	cairo_line_to (cr, arrow_width / 2.0 - line_width_2, 0);
+	cairo_line_to (cr, arrow_width / 2.0, line_width_2);
+	cairo_line_to (cr, 0, arrow_height);
+	cairo_close_path (cr);
 	
-	cairo_set_source_rgb (cr, color->r, color->g, color->b);
-	cairo_stroke (cr);	
+	ge_cairo_set_color (cr, color);
+	cairo_fill (cr);
+	
+	cairo_restore (cr);
 }
 
 static void
 clearlooks_draw_combo_arrow (cairo_t *cr, CairoColor *color,
                              double x, double y, double width, double height)
 {
-	const int ARROW_WIDTH   = 5;
-	const float ARROW_HEIGHT  = 2;
-	const float ARROW_SPACING = 7;
+	double arrow_width = MIN (height * 2 / 3.0, width);
+	double arrow_height = arrow_width / 2.0;
+	double gap_size = 1.0 * arrow_height;
 	
-	cairo_set_line_width (cr, 1.5);
-
-	y -= ARROW_SPACING/2;
+	cairo_save (cr);
+	cairo_translate (cr, x, y - (arrow_height + gap_size) / 2.0);
+	cairo_rotate (cr, G_PI);
+	clearlooks_draw_normal_arrow (cr, color, 0, 0, arrow_width, arrow_height);
+	cairo_restore (cr);
 	
-	cairo_move_to (cr, -ARROW_WIDTH/2, y + ARROW_HEIGHT/2);
-	cairo_line_to   (cr, 0, y + -ARROW_HEIGHT/2);
-	cairo_line_to   (cr, ARROW_WIDTH/2, y + ARROW_HEIGHT/2);
-	cairo_set_source_rgb (cr, color->r, color->g, color->b);	
-	cairo_stroke (cr);
-	
-	y += ARROW_SPACING;
-	
-	cairo_move_to (cr, -ARROW_WIDTH/2, y + -ARROW_HEIGHT/2);
-	cairo_line_to   (cr, 0, y + ARROW_HEIGHT/2);
-	cairo_line_to   (cr, ARROW_WIDTH/2, y + -ARROW_HEIGHT/2);
-	cairo_set_source_rgb (cr, color->r, color->g, color->b);	
-	cairo_stroke (cr);
+	clearlooks_draw_normal_arrow (cr, color, x, y + (arrow_height + gap_size) / 2.0, arrow_width, arrow_height);
 }
 
 static void
@@ -2052,8 +2104,10 @@ _clearlooks_draw_arrow (cairo_t *cr, CairoColor *color,
 		rotate = G_PI*0.5;
 	else if (dir == CL_DIRECTION_UP)
 		rotate = G_PI;
-	else
+	else if (dir == CL_DIRECTION_DOWN)
 		rotate = 0;
+	else
+		return;
 	
 	if (type == CL_ARROW_NORMAL)
 	{
@@ -2075,19 +2129,11 @@ clearlooks_draw_arrow (cairo_t *cr,
                        const ArrowParameters           *arrow,
                        int x, int y, int width, int height)
 {
-	CairoColor *color = (CairoColor*)&colors->text[widget->state_type];
+	CairoColor *color = (CairoColor*)&colors->fg[widget->state_type];
 	gdouble tx, ty;
 	
-	if (arrow->direction == CL_DIRECTION_DOWN || arrow->direction == CL_DIRECTION_UP)
-	{
-		tx = x + width/2;
-		ty = (y + height/2) + 0.5;
-	}
-	else
-	{
-		tx = (x + width/2) + 0.5;
-		ty = y + height/2;
-	}
+	tx = x + width/2.0;
+	ty = y + height/2.0;
 	
 	if (widget->disabled)
 	{
