@@ -110,7 +110,7 @@ clearlooks_glossy_draw_button (cairo_t *cr,
 		
 		/* Use inset as default for now - would be nice to make this an option */
 		/* if (params->active || shadow->shadow == CL_SHADOW_IN) */
-			params->style_functions->draw_inset (cr, width-1, height-1, params->radius, params->corners);
+			params->style_functions->draw_inset (cr, colors, width-1, height-1, params->radius, params->corners);
 		/* else
 			clearlooks_draw_shadow (cr, params->radius, width-1, height-1);
 		*/
@@ -194,11 +194,17 @@ clearlooks_glossy_draw_tab (cairo_t *cr,
 {
 	const CairoColor *background;
 	FrameParameters frame;
-	GdkRectangle pos = { x, y, width, height };
+	GdkRectangle real_pos;
 	double radius = MIN (params->radius, MIN ((width - 2.0) / 2.0, (height - 2.0) / 2.0));
 	
 	background = &colors->bg[params->state_type];
 	
+	/* make a backup of x,y,width,height */
+	real_pos.x = x;
+	real_pos.y = y;
+	real_pos.width  = width;
+	real_pos.height = height;
+	
 	cairo_save (cr);
 	{
 		CairoColor a, b, c, d, e;
@@ -257,10 +263,10 @@ clearlooks_glossy_draw_tab (cairo_t *cr,
 	}
 	cairo_restore (cr);
 	
-	x = pos.x;
-	y = pos.y;
-	width = pos.width;
-	height = pos.height;
+	x = real_pos.x;
+	y = real_pos.y;
+	width  = real_pos.width;
+	height = real_pos.height;
 	
 	frame.shadow = CL_SHADOW_OUT;
 	frame.gap_side = tab->gap_side;
@@ -333,7 +339,7 @@ clearlooks_glossy_draw_slider_button (cairo_t *cr,
 
 	cairo_translate (cr, x+0.5, y+0.5);
 	
-	params->style_functions->draw_shadow (cr, radius, width-1, height-1);
+	params->style_functions->draw_shadow (cr, colors, radius, width-1, height-1);
 	params->style_functions->draw_slider (cr, colors, params, 1, 1, width-2, height-2);
 }
 
@@ -406,7 +412,7 @@ clearlooks_glossy_draw_checkbox (cairo_t *cr,
 		
 		if (widget->state_type != GTK_STATE_INSENSITIVE)
 		{
-			// glow
+			/* glow */
 			if ((widget->prelight || (widget->active && !draw_bullet)) && !checkbox->in_cell) 
 			{
 				const CairoColor *glow = &colors->spot[0];
@@ -415,7 +421,7 @@ clearlooks_glossy_draw_checkbox (cairo_t *cr,
 				cairo_stroke (cr);
 			}
 			
-			// shadow
+			/* shadow */
 			if (checkbox->in_cell) {
 				ge_cairo_rounded_rectangle (cr, x+0.5, y+0.5, width, height, 1, widget->corners);
 			} else {
@@ -502,22 +508,8 @@ clearlooks_glossy_draw_menuitem (cairo_t                   *cr,
 	cairo_restore (cr);
 
 	ge_cairo_set_color (cr, &colors->spot[2]);
-	/* TODO: only draw full border if horiztonal padding is > 1
-	if (params->horizontal_padding > 1)
-	{
-		cairo_rectangle (cr, x+ 0.5, y+0.5, width - 1.0, height - 1.0);
-		cairo_stroke (cr);
-	}
-	else
-	{
-	*/
-		cairo_move_to (cr, x + 0.5, y + 0.5);
-		cairo_line_to (cr, width, y + 0.5);
-		cairo_stroke (cr);
-		cairo_move_to (cr, x + 0.5, y + height - 0.5);
-		cairo_line_to (cr, width, y + height - 0.5);
-		cairo_stroke (cr);
-	/*}*/
+	cairo_rectangle (cr, x+ 0.5, y+0.5, width - 1.0, height - 1.0);
+	cairo_stroke (cr);
 }
 
 static void
@@ -624,7 +616,7 @@ clearlooks_glossy_draw_radiobutton (cairo_t *cr,
 		
 		if ( widget->state_type != GTK_STATE_INSENSITIVE )
 		{
-			// glow
+			/* glow */
 			if (widget->prelight || (widget->active && !draw_bullet)) 
 			{
 				const CairoColor *glow = &colors->spot[0];
@@ -633,7 +625,7 @@ clearlooks_glossy_draw_radiobutton (cairo_t *cr,
 				cairo_stroke (cr);
 			}
 		
-			// shadow
+			/* shadow */
 			cairo_arc (cr, x+width/2.0+1, y+height/2.0+1, width/2.0 - 1.0, 0, 2 * G_PI);
 			cairo_set_source_rgba (cr, 0., 0., 0., 0.2);
 			cairo_stroke (cr);
@@ -658,7 +650,7 @@ clearlooks_glossy_draw_radiobutton (cairo_t *cr,
 		cairo_stroke (cr);
 	}
 	
-	// draw the bullet
+	/* draw the bullet */
 	cairo_translate (cr, x, y);
 	cairo_scale (cr, width / 13.0, height / 13.0);
 	if (draw_bullet)
