@@ -408,13 +408,14 @@ clearlooks_inverted_draw_menuitem (cairo_t *cr,
 {
 	CairoColor *fill = (CairoColor*)&colors->spot[1];
 	CairoColor fill_shade;
-	CairoColor *border = (CairoColor*)&colors->spot[2];
+	CairoColor border = colors->spot[2];
 	cairo_pattern_t *pattern;
 
+	ge_shade_color (&border, 1.05, &border);
 	ge_shade_color (fill, 0.85, &fill_shade);
 	cairo_set_line_width (cr, 1.0);
 
-	cairo_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1);
+	ge_cairo_rounded_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1, widget->radius, widget->corners);
 
 	pattern = cairo_pattern_create_linear (x, y, x, y + height);
 	cairo_pattern_add_color_stop_rgb (pattern, 0, fill_shade.r, fill_shade.g, fill_shade.b);
@@ -424,7 +425,7 @@ clearlooks_inverted_draw_menuitem (cairo_t *cr,
 	cairo_fill_preserve  (cr);
 	cairo_pattern_destroy (pattern);
 
-	ge_cairo_set_color (cr, border);
+	ge_cairo_set_color (cr, &border);
 	cairo_stroke (cr);
 }
 
@@ -436,9 +437,10 @@ clearlooks_inverted_draw_menubaritem (cairo_t *cr,
 {
 	CairoColor *fill = (CairoColor*)&colors->spot[1];
 	CairoColor fill_shade;
-	CairoColor *border = (CairoColor*)&colors->spot[2];
+	CairoColor border = colors->spot[2];
 	cairo_pattern_t *pattern;
 	
+	ge_shade_color (&border, 1.05, &border);
 	ge_shade_color (fill, 0.85, &fill_shade);
 	
 	cairo_set_line_width (cr, 1.0);
@@ -452,7 +454,7 @@ clearlooks_inverted_draw_menubaritem (cairo_t *cr,
 	cairo_fill_preserve  (cr);
 	cairo_pattern_destroy (pattern);
 
-	ge_cairo_set_color (cr, border);
+	ge_cairo_set_color (cr, &border);
 	cairo_stroke_preserve (cr);
 }
 
