@@ -11,7 +11,8 @@ typedef enum
 {
 	CL_STYLE_CLASSIC = 0,
 	CL_STYLE_GLOSSY = 1,
-	CL_NUM_STYLES = 2
+	CL_STYLE_INVERTED = 2,
+	CL_NUM_STYLES = 3
 } ClearlooksStyles;
 
 
@@ -119,6 +120,7 @@ typedef struct
 
 typedef struct
 {
+	CairoColor fg[5];
 	CairoColor bg[5];
 	CairoColor base[5];
 	CairoColor text[5];
@@ -235,6 +237,11 @@ typedef struct
 	boolean              in_menu;
 } CheckboxParameters;
 
+typedef struct
+{
+	ClearlooksArrowType type;
+	ClearlooksDirection direction;
+} ArrowParameters;
 
 struct _ClearlooksStyleFunctions
 {
@@ -288,6 +295,7 @@ struct _ClearlooksStyleFunctions
 	                               int x, int y, int width, int height);
 					   
 	void (*draw_inset)            (cairo_t				*cr,
+                                   const ClearlooksColors		*colors,
 	                               int width, int height,
 	                               double radius, uint8 corners);
 
@@ -381,6 +389,12 @@ struct _ClearlooksStyleFunctions
 	                               const WidgetParameters		*widget,
 	                               const ResizeGripParameters	*grip,
 	                               int x, int y, int width, int height);
+
+	void (*draw_arrow)      (cairo_t				*cr,
+					                       const ClearlooksColors          *colors,
+					                       const WidgetParameters          *widget,
+					                       const ArrowParameters           *arrow,
+					                       int x, int y, int width, int height);
 	                               
 	void (*draw_checkbox)         (cairo_t				*cr,
 	                               const ClearlooksColors		*colors,
@@ -397,6 +411,7 @@ struct _ClearlooksStyleFunctions
 	/* Style internal functions */
 	/* XXX: Only used by slider_button, inline it? */
 	void (*draw_shadow)           (cairo_t				*cr,
+                                   const ClearlooksColors		*colors,
 	                               gfloat                            radius,
 	                               int				 width,
 	                               int				 height);
@@ -406,9 +421,10 @@ struct _ClearlooksStyleFunctions
 	                               const WidgetParameters		*widget,
 	                               int x, int y, int width, int height);
 
-	void (*draw_gripdots)         (cairo_t *cr, int x, int y,
-                                       int width, int height, int xr, int yr,
-                                       float contrast);
+	void (*draw_gripdots)         (cairo_t *cr,
+                                    const ClearlooksColors *colors, int x, int y,
+                                    int width, int height, int xr, int yr,
+                                    float contrast);
 };
 
 
